from sqlspec.adapters.duckdb.config import DuckDBConfig
from sqlspec.adapters.duckdb.driver import DuckDBDriver

__all__ = (
    "DuckDBConfig",
    "DuckDBDriver",
)
